# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['PipelineTriggerArgs', 'PipelineTrigger']

@pulumi.input_type
class PipelineTriggerArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[_builtins.str],
                 project: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a PipelineTrigger resource.
        :param pulumi.Input[_builtins.str] description: The description of the pipeline trigger.
        :param pulumi.Input[_builtins.str] project: The name or id of the project to add the trigger to.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "project", project)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Input[_builtins.str]:
        """
        The description of the pipeline trigger.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The name or id of the project to add the trigger to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)


@pulumi.input_type
class _PipelineTriggerState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_trigger_id: Optional[pulumi.Input[_builtins.int]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PipelineTrigger resources.
        :param pulumi.Input[_builtins.str] description: The description of the pipeline trigger.
        :param pulumi.Input[_builtins.int] pipeline_trigger_id: The pipeline trigger id.
        :param pulumi.Input[_builtins.str] project: The name or id of the project to add the trigger to.
        :param pulumi.Input[_builtins.str] token: The pipeline trigger token. This value is not available during import.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if pipeline_trigger_id is not None:
            pulumi.set(__self__, "pipeline_trigger_id", pipeline_trigger_id)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if token is not None:
            pulumi.set(__self__, "token", token)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the pipeline trigger.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="pipelineTriggerId")
    def pipeline_trigger_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The pipeline trigger id.
        """
        return pulumi.get(self, "pipeline_trigger_id")

    @pipeline_trigger_id.setter
    def pipeline_trigger_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "pipeline_trigger_id", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name or id of the project to add the trigger to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The pipeline trigger token. This value is not available during import.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)


@pulumi.type_token("gitlab:index/pipelineTrigger:PipelineTrigger")
class PipelineTrigger(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `PipelineTrigger` resource allows to manage the lifecycle of a pipeline trigger.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/pipeline_triggers/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.PipelineTrigger("example",
            project="12345",
            description="Used to trigger builds")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_pipeline_trigger`. For example:

        terraform

        import {

          to = gitlab_pipeline_trigger.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab pipeline triggers can be imported using an id made up of `{project_id}:{pipeline_trigger_id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/pipelineTrigger:PipelineTrigger test 1:3
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the pipeline trigger.
        :param pulumi.Input[_builtins.str] project: The name or id of the project to add the trigger to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PipelineTriggerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `PipelineTrigger` resource allows to manage the lifecycle of a pipeline trigger.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/pipeline_triggers/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.PipelineTrigger("example",
            project="12345",
            description="Used to trigger builds")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_pipeline_trigger`. For example:

        terraform

        import {

          to = gitlab_pipeline_trigger.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab pipeline triggers can be imported using an id made up of `{project_id}:{pipeline_trigger_id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/pipelineTrigger:PipelineTrigger test 1:3
        ```

        :param str resource_name: The name of the resource.
        :param PipelineTriggerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PipelineTriggerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PipelineTriggerArgs.__new__(PipelineTriggerArgs)

            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["pipeline_trigger_id"] = None
            __props__.__dict__["token"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(PipelineTrigger, __self__).__init__(
            'gitlab:index/pipelineTrigger:PipelineTrigger',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            pipeline_trigger_id: Optional[pulumi.Input[_builtins.int]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            token: Optional[pulumi.Input[_builtins.str]] = None) -> 'PipelineTrigger':
        """
        Get an existing PipelineTrigger resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the pipeline trigger.
        :param pulumi.Input[_builtins.int] pipeline_trigger_id: The pipeline trigger id.
        :param pulumi.Input[_builtins.str] project: The name or id of the project to add the trigger to.
        :param pulumi.Input[_builtins.str] token: The pipeline trigger token. This value is not available during import.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PipelineTriggerState.__new__(_PipelineTriggerState)

        __props__.__dict__["description"] = description
        __props__.__dict__["pipeline_trigger_id"] = pipeline_trigger_id
        __props__.__dict__["project"] = project
        __props__.__dict__["token"] = token
        return PipelineTrigger(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        The description of the pipeline trigger.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="pipelineTriggerId")
    def pipeline_trigger_id(self) -> pulumi.Output[_builtins.int]:
        """
        The pipeline trigger id.
        """
        return pulumi.get(self, "pipeline_trigger_id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The name or id of the project to add the trigger to.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def token(self) -> pulumi.Output[_builtins.str]:
        """
        The pipeline trigger token. This value is not available during import.
        """
        return pulumi.get(self, "token")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetCurrentUserResult',
    'AwaitableGetCurrentUserResult',
    'get_current_user',
    'get_current_user_output',
]

@pulumi.output_type
class GetCurrentUserResult:
    """
    A collection of values returned by getCurrentUser.
    """
    def __init__(__self__, bot=None, global_id=None, global_namespace_id=None, group_count=None, id=None, name=None, namespace_id=None, public_email=None, username=None):
        if bot and not isinstance(bot, bool):
            raise TypeError("Expected argument 'bot' to be a bool")
        pulumi.set(__self__, "bot", bot)
        if global_id and not isinstance(global_id, str):
            raise TypeError("Expected argument 'global_id' to be a str")
        pulumi.set(__self__, "global_id", global_id)
        if global_namespace_id and not isinstance(global_namespace_id, str):
            raise TypeError("Expected argument 'global_namespace_id' to be a str")
        pulumi.set(__self__, "global_namespace_id", global_namespace_id)
        if group_count and not isinstance(group_count, int):
            raise TypeError("Expected argument 'group_count' to be a int")
        pulumi.set(__self__, "group_count", group_count)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if namespace_id and not isinstance(namespace_id, str):
            raise TypeError("Expected argument 'namespace_id' to be a str")
        pulumi.set(__self__, "namespace_id", namespace_id)
        if public_email and not isinstance(public_email, str):
            raise TypeError("Expected argument 'public_email' to be a str")
        pulumi.set(__self__, "public_email", public_email)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def bot(self) -> _builtins.bool:
        """
        Indicates if the user is a bot.
        """
        return pulumi.get(self, "bot")

    @_builtins.property
    @pulumi.getter(name="globalId")
    def global_id(self) -> _builtins.str:
        """
        Global ID of the user. This is in the form of a GraphQL globally unique ID.
        """
        return pulumi.get(self, "global_id")

    @_builtins.property
    @pulumi.getter(name="globalNamespaceId")
    def global_namespace_id(self) -> _builtins.str:
        """
        Personal namespace of the user. This is in the form of a GraphQL globally unique ID.
        """
        return pulumi.get(self, "global_namespace_id")

    @_builtins.property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> _builtins.int:
        """
        Group count for the user.
        """
        return pulumi.get(self, "group_count")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the user.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Human-readable name of the user. Returns **** if the user is a project bot and the requester does not have permission to view the project.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> _builtins.str:
        """
        Personal namespace of the user.
        """
        return pulumi.get(self, "namespace_id")

    @_builtins.property
    @pulumi.getter(name="publicEmail")
    def public_email(self) -> _builtins.str:
        """
        User's public email.
        """
        return pulumi.get(self, "public_email")

    @_builtins.property
    @pulumi.getter
    def username(self) -> _builtins.str:
        """
        Username of the user. Unique within this instance of GitLab.
        """
        return pulumi.get(self, "username")


class AwaitableGetCurrentUserResult(GetCurrentUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCurrentUserResult(
            bot=self.bot,
            global_id=self.global_id,
            global_namespace_id=self.global_namespace_id,
            group_count=self.group_count,
            id=self.id,
            name=self.name,
            namespace_id=self.namespace_id,
            public_email=self.public_email,
            username=self.username)


def get_current_user(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCurrentUserResult:
    """
    The `get_current_user` data source allows details of the current user (determined by `token` provider attribute) to be retrieved.

    **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/index/#querycurrentuser)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_current_user()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getCurrentUser:getCurrentUser', __args__, opts=opts, typ=GetCurrentUserResult).value

    return AwaitableGetCurrentUserResult(
        bot=pulumi.get(__ret__, 'bot'),
        global_id=pulumi.get(__ret__, 'global_id'),
        global_namespace_id=pulumi.get(__ret__, 'global_namespace_id'),
        group_count=pulumi.get(__ret__, 'group_count'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        namespace_id=pulumi.get(__ret__, 'namespace_id'),
        public_email=pulumi.get(__ret__, 'public_email'),
        username=pulumi.get(__ret__, 'username'))
def get_current_user_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCurrentUserResult]:
    """
    The `get_current_user` data source allows details of the current user (determined by `token` provider attribute) to be retrieved.

    **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/index/#querycurrentuser)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_current_user()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getCurrentUser:getCurrentUser', __args__, opts=opts, typ=GetCurrentUserResult)
    return __ret__.apply(lambda __response__: GetCurrentUserResult(
        bot=pulumi.get(__response__, 'bot'),
        global_id=pulumi.get(__response__, 'global_id'),
        global_namespace_id=pulumi.get(__response__, 'global_namespace_id'),
        group_count=pulumi.get(__response__, 'group_count'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        namespace_id=pulumi.get(__response__, 'namespace_id'),
        public_email=pulumi.get(__response__, 'public_email'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectExternalStatusCheckArgs', 'ProjectExternalStatusCheck']

@pulumi.input_type
class ProjectExternalStatusCheckArgs:
    def __init__(__self__, *,
                 external_url: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.int],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protected_branch_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 shared_secret: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ProjectExternalStatusCheck resource.
        :param pulumi.Input[_builtins.str] external_url: The URL of the external status check service.
        :param pulumi.Input[_builtins.int] project_id: The ID of the project.
        :param pulumi.Input[_builtins.str] name: The display name of the external status check service.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] protected_branch_ids: The list of IDs of protected branches to scope the rule by.
        :param pulumi.Input[_builtins.str] shared_secret: The HMAC secret for the external status check.  If this is set, then removed from the config, the value will get set to empty in the state.
        """
        pulumi.set(__self__, "external_url", external_url)
        pulumi.set(__self__, "project_id", project_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protected_branch_ids is not None:
            pulumi.set(__self__, "protected_branch_ids", protected_branch_ids)
        if shared_secret is not None:
            pulumi.set(__self__, "shared_secret", shared_secret)

    @_builtins.property
    @pulumi.getter(name="externalUrl")
    def external_url(self) -> pulumi.Input[_builtins.str]:
        """
        The URL of the external status check service.
        """
        return pulumi.get(self, "external_url")

    @external_url.setter
    def external_url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "external_url", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.int]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of the external status check service.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="protectedBranchIds")
    def protected_branch_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        The list of IDs of protected branches to scope the rule by.
        """
        return pulumi.get(self, "protected_branch_ids")

    @protected_branch_ids.setter
    def protected_branch_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "protected_branch_ids", value)

    @_builtins.property
    @pulumi.getter(name="sharedSecret")
    def shared_secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The HMAC secret for the external status check.  If this is set, then removed from the config, the value will get set to empty in the state.
        """
        return pulumi.get(self, "shared_secret")

    @shared_secret.setter
    def shared_secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shared_secret", value)


@pulumi.input_type
class _ProjectExternalStatusCheckState:
    def __init__(__self__, *,
                 external_url: Optional[pulumi.Input[_builtins.str]] = None,
                 hmac: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.int]] = None,
                 protected_branch_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 shared_secret: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectExternalStatusCheck resources.
        :param pulumi.Input[_builtins.str] external_url: The URL of the external status check service.
        :param pulumi.Input[_builtins.bool] hmac: True if the external status check uses an HMAC secret.
        :param pulumi.Input[_builtins.str] name: The display name of the external status check service.
        :param pulumi.Input[_builtins.int] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] protected_branch_ids: The list of IDs of protected branches to scope the rule by.
        :param pulumi.Input[_builtins.str] shared_secret: The HMAC secret for the external status check.  If this is set, then removed from the config, the value will get set to empty in the state.
        """
        if external_url is not None:
            pulumi.set(__self__, "external_url", external_url)
        if hmac is not None:
            pulumi.set(__self__, "hmac", hmac)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if protected_branch_ids is not None:
            pulumi.set(__self__, "protected_branch_ids", protected_branch_ids)
        if shared_secret is not None:
            pulumi.set(__self__, "shared_secret", shared_secret)

    @_builtins.property
    @pulumi.getter(name="externalUrl")
    def external_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the external status check service.
        """
        return pulumi.get(self, "external_url")

    @external_url.setter
    def external_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_url", value)

    @_builtins.property
    @pulumi.getter
    def hmac(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        True if the external status check uses an HMAC secret.
        """
        return pulumi.get(self, "hmac")

    @hmac.setter
    def hmac(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hmac", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of the external status check service.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="protectedBranchIds")
    def protected_branch_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        The list of IDs of protected branches to scope the rule by.
        """
        return pulumi.get(self, "protected_branch_ids")

    @protected_branch_ids.setter
    def protected_branch_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "protected_branch_ids", value)

    @_builtins.property
    @pulumi.getter(name="sharedSecret")
    def shared_secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The HMAC secret for the external status check.  If this is set, then removed from the config, the value will get set to empty in the state.
        """
        return pulumi.get(self, "shared_secret")

    @shared_secret.setter
    def shared_secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shared_secret", value)


@pulumi.type_token("gitlab:index/projectExternalStatusCheck:ProjectExternalStatusCheck")
class ProjectExternalStatusCheck(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 external_url: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.int]] = None,
                 protected_branch_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 shared_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `ProjectExternalStatusCheck` resource allows you to manage the lifecycle of an external status check service on a project.

        > This resource requires a GitLab Enterprise instance with an Ultimate license.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/status_checks/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.ProjectExternalStatusCheck("foo",
            project_id=123,
            name="foo",
            external_url="https://example.gitlab.com")
        bar = gitlab.ProjectExternalStatusCheck("bar",
            project_id=456,
            name="bar",
            external_url="https://example.gitlab.com",
            shared_secret="secret",
            protected_branch_ids=[
                6,
                28,
            ])
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_external_status_check`. For example:

        terraform

        import {

          to = gitlab_project_external_status_check.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab project external status checks can be imported using an id made up of `<project-id>:<external-check-id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectExternalStatusCheck:ProjectExternalStatusCheck foo "123:42"
        ```

        NOTE: the `shared_secret` resource attribute is not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] external_url: The URL of the external status check service.
        :param pulumi.Input[_builtins.str] name: The display name of the external status check service.
        :param pulumi.Input[_builtins.int] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] protected_branch_ids: The list of IDs of protected branches to scope the rule by.
        :param pulumi.Input[_builtins.str] shared_secret: The HMAC secret for the external status check.  If this is set, then removed from the config, the value will get set to empty in the state.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectExternalStatusCheckArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectExternalStatusCheck` resource allows you to manage the lifecycle of an external status check service on a project.

        > This resource requires a GitLab Enterprise instance with an Ultimate license.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/status_checks/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.ProjectExternalStatusCheck("foo",
            project_id=123,
            name="foo",
            external_url="https://example.gitlab.com")
        bar = gitlab.ProjectExternalStatusCheck("bar",
            project_id=456,
            name="bar",
            external_url="https://example.gitlab.com",
            shared_secret="secret",
            protected_branch_ids=[
                6,
                28,
            ])
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_external_status_check`. For example:

        terraform

        import {

          to = gitlab_project_external_status_check.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab project external status checks can be imported using an id made up of `<project-id>:<external-check-id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectExternalStatusCheck:ProjectExternalStatusCheck foo "123:42"
        ```

        NOTE: the `shared_secret` resource attribute is not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param ProjectExternalStatusCheckArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectExternalStatusCheckArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 external_url: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.int]] = None,
                 protected_branch_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 shared_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectExternalStatusCheckArgs.__new__(ProjectExternalStatusCheckArgs)

            if external_url is None and not opts.urn:
                raise TypeError("Missing required property 'external_url'")
            __props__.__dict__["external_url"] = external_url
            __props__.__dict__["name"] = name
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["protected_branch_ids"] = protected_branch_ids
            __props__.__dict__["shared_secret"] = None if shared_secret is None else pulumi.Output.secret(shared_secret)
            __props__.__dict__["hmac"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["sharedSecret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ProjectExternalStatusCheck, __self__).__init__(
            'gitlab:index/projectExternalStatusCheck:ProjectExternalStatusCheck',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            external_url: Optional[pulumi.Input[_builtins.str]] = None,
            hmac: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.int]] = None,
            protected_branch_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
            shared_secret: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectExternalStatusCheck':
        """
        Get an existing ProjectExternalStatusCheck resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] external_url: The URL of the external status check service.
        :param pulumi.Input[_builtins.bool] hmac: True if the external status check uses an HMAC secret.
        :param pulumi.Input[_builtins.str] name: The display name of the external status check service.
        :param pulumi.Input[_builtins.int] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] protected_branch_ids: The list of IDs of protected branches to scope the rule by.
        :param pulumi.Input[_builtins.str] shared_secret: The HMAC secret for the external status check.  If this is set, then removed from the config, the value will get set to empty in the state.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectExternalStatusCheckState.__new__(_ProjectExternalStatusCheckState)

        __props__.__dict__["external_url"] = external_url
        __props__.__dict__["hmac"] = hmac
        __props__.__dict__["name"] = name
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["protected_branch_ids"] = protected_branch_ids
        __props__.__dict__["shared_secret"] = shared_secret
        return ProjectExternalStatusCheck(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="externalUrl")
    def external_url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the external status check service.
        """
        return pulumi.get(self, "external_url")

    @_builtins.property
    @pulumi.getter
    def hmac(self) -> pulumi.Output[_builtins.bool]:
        """
        True if the external status check uses an HMAC secret.
        """
        return pulumi.get(self, "hmac")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The display name of the external status check service.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.int]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="protectedBranchIds")
    def protected_branch_ids(self) -> pulumi.Output[Sequence[_builtins.int]]:
        """
        The list of IDs of protected branches to scope the rule by.
        """
        return pulumi.get(self, "protected_branch_ids")

    @_builtins.property
    @pulumi.getter(name="sharedSecret")
    def shared_secret(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The HMAC secret for the external status check.  If this is set, then removed from the config, the value will get set to empty in the state.
        """
        return pulumi.get(self, "shared_secret")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetReleaseLinksResult',
    'AwaitableGetReleaseLinksResult',
    'get_release_links',
    'get_release_links_output',
]

@pulumi.output_type
class GetReleaseLinksResult:
    """
    A collection of values returned by getReleaseLinks.
    """
    def __init__(__self__, id=None, project=None, release_links=None, tag_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if release_links and not isinstance(release_links, list):
            raise TypeError("Expected argument 'release_links' to be a list")
        pulumi.set(__self__, "release_links", release_links)
        if tag_name and not isinstance(tag_name, str):
            raise TypeError("Expected argument 'tag_name' to be a str")
        pulumi.set(__self__, "tag_name", tag_name)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this data source.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The ID or [URL-encoded path of the project](https://docs.gitlab.com/api/index/#namespaced-path-encoding).
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="releaseLinks")
    def release_links(self) -> Sequence['outputs.GetReleaseLinksReleaseLinkResult']:
        """
        List of release links
        """
        return pulumi.get(self, "release_links")

    @_builtins.property
    @pulumi.getter(name="tagName")
    def tag_name(self) -> _builtins.str:
        """
        The tag associated with the Release.
        """
        return pulumi.get(self, "tag_name")


class AwaitableGetReleaseLinksResult(GetReleaseLinksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetReleaseLinksResult(
            id=self.id,
            project=self.project,
            release_links=self.release_links,
            tag_name=self.tag_name)


def get_release_links(project: Optional[_builtins.str] = None,
                      tag_name: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetReleaseLinksResult:
    """
    The `get_release_links` data source allows get details of release links.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/releases/links/)


    :param _builtins.str project: The ID or [URL-encoded path of the project](https://docs.gitlab.com/api/index/#namespaced-path-encoding).
    :param _builtins.str tag_name: The tag associated with the Release.
    """
    __args__ = dict()
    __args__['project'] = project
    __args__['tagName'] = tag_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getReleaseLinks:getReleaseLinks', __args__, opts=opts, typ=GetReleaseLinksResult).value

    return AwaitableGetReleaseLinksResult(
        id=pulumi.get(__ret__, 'id'),
        project=pulumi.get(__ret__, 'project'),
        release_links=pulumi.get(__ret__, 'release_links'),
        tag_name=pulumi.get(__ret__, 'tag_name'))
def get_release_links_output(project: Optional[pulumi.Input[_builtins.str]] = None,
                             tag_name: Optional[pulumi.Input[_builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetReleaseLinksResult]:
    """
    The `get_release_links` data source allows get details of release links.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/releases/links/)


    :param _builtins.str project: The ID or [URL-encoded path of the project](https://docs.gitlab.com/api/index/#namespaced-path-encoding).
    :param _builtins.str tag_name: The tag associated with the Release.
    """
    __args__ = dict()
    __args__['project'] = project
    __args__['tagName'] = tag_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getReleaseLinks:getReleaseLinks', __args__, opts=opts, typ=GetReleaseLinksResult)
    return __ret__.apply(lambda __response__: GetReleaseLinksResult(
        id=pulumi.get(__response__, 'id'),
        project=pulumi.get(__response__, 'project'),
        release_links=pulumi.get(__response__, 'release_links'),
        tag_name=pulumi.get(__response__, 'tag_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetProjectMirrorPublicKeyResult',
    'AwaitableGetProjectMirrorPublicKeyResult',
    'get_project_mirror_public_key',
    'get_project_mirror_public_key_output',
]

@pulumi.output_type
class GetProjectMirrorPublicKeyResult:
    """
    A collection of values returned by getProjectMirrorPublicKey.
    """
    def __init__(__self__, id=None, mirror_id=None, project_id=None, public_key=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if mirror_id and not isinstance(mirror_id, int):
            raise TypeError("Expected argument 'mirror_id' to be a int")
        pulumi.set(__self__, "mirror_id", mirror_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if public_key and not isinstance(public_key, str):
            raise TypeError("Expected argument 'public_key' to be a str")
        pulumi.set(__self__, "public_key", public_key)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="mirrorId")
    def mirror_id(self) -> _builtins.int:
        """
        The id of the remote mirror.
        """
        return pulumi.get(self, "mirror_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The integer or path with namespace that uniquely identifies the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> _builtins.str:
        """
        Public key of the remote mirror.
        """
        return pulumi.get(self, "public_key")


class AwaitableGetProjectMirrorPublicKeyResult(GetProjectMirrorPublicKeyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectMirrorPublicKeyResult(
            id=self.id,
            mirror_id=self.mirror_id,
            project_id=self.project_id,
            public_key=self.public_key)


def get_project_mirror_public_key(mirror_id: Optional[_builtins.int] = None,
                                  project_id: Optional[_builtins.str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectMirrorPublicKeyResult:
    """
    The `get_project_mirror_public_key` data source allows the public key of a project mirror to be retrieved by its mirror id and the project it belongs to.

    **Note**: Supported on GitLab 17.9 or higher.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/remote_mirrors/#get-a-single-projects-remote-mirror-public-key)


    :param _builtins.int mirror_id: The id of the remote mirror.
    :param _builtins.str project_id: The integer or path with namespace that uniquely identifies the project.
    """
    __args__ = dict()
    __args__['mirrorId'] = mirror_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectMirrorPublicKey:getProjectMirrorPublicKey', __args__, opts=opts, typ=GetProjectMirrorPublicKeyResult).value

    return AwaitableGetProjectMirrorPublicKeyResult(
        id=pulumi.get(__ret__, 'id'),
        mirror_id=pulumi.get(__ret__, 'mirror_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        public_key=pulumi.get(__ret__, 'public_key'))
def get_project_mirror_public_key_output(mirror_id: Optional[pulumi.Input[_builtins.int]] = None,
                                         project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectMirrorPublicKeyResult]:
    """
    The `get_project_mirror_public_key` data source allows the public key of a project mirror to be retrieved by its mirror id and the project it belongs to.

    **Note**: Supported on GitLab 17.9 or higher.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/remote_mirrors/#get-a-single-projects-remote-mirror-public-key)


    :param _builtins.int mirror_id: The id of the remote mirror.
    :param _builtins.str project_id: The integer or path with namespace that uniquely identifies the project.
    """
    __args__ = dict()
    __args__['mirrorId'] = mirror_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectMirrorPublicKey:getProjectMirrorPublicKey', __args__, opts=opts, typ=GetProjectMirrorPublicKeyResult)
    return __ret__.apply(lambda __response__: GetProjectMirrorPublicKeyResult(
        id=pulumi.get(__response__, 'id'),
        mirror_id=pulumi.get(__response__, 'mirror_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        public_key=pulumi.get(__response__, 'public_key')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetGroupResult',
    'AwaitableGetGroupResult',
    'get_group',
    'get_group_output',
]

@pulumi.output_type
class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, default_branch=None, default_branch_protection=None, description=None, extra_shared_runners_minutes_limit=None, full_name=None, full_path=None, group_id=None, id=None, lfs_enabled=None, membership_lock=None, name=None, parent_id=None, path=None, prevent_forking_outside_group=None, request_access_enabled=None, runners_token=None, shared_runners_minutes_limit=None, shared_runners_setting=None, shared_with_groups=None, visibility_level=None, web_url=None, wiki_access_level=None):
        if default_branch and not isinstance(default_branch, str):
            raise TypeError("Expected argument 'default_branch' to be a str")
        pulumi.set(__self__, "default_branch", default_branch)
        if default_branch_protection and not isinstance(default_branch_protection, int):
            raise TypeError("Expected argument 'default_branch_protection' to be a int")
        pulumi.set(__self__, "default_branch_protection", default_branch_protection)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if extra_shared_runners_minutes_limit and not isinstance(extra_shared_runners_minutes_limit, int):
            raise TypeError("Expected argument 'extra_shared_runners_minutes_limit' to be a int")
        pulumi.set(__self__, "extra_shared_runners_minutes_limit", extra_shared_runners_minutes_limit)
        if full_name and not isinstance(full_name, str):
            raise TypeError("Expected argument 'full_name' to be a str")
        pulumi.set(__self__, "full_name", full_name)
        if full_path and not isinstance(full_path, str):
            raise TypeError("Expected argument 'full_path' to be a str")
        pulumi.set(__self__, "full_path", full_path)
        if group_id and not isinstance(group_id, int):
            raise TypeError("Expected argument 'group_id' to be a int")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lfs_enabled and not isinstance(lfs_enabled, bool):
            raise TypeError("Expected argument 'lfs_enabled' to be a bool")
        pulumi.set(__self__, "lfs_enabled", lfs_enabled)
        if membership_lock and not isinstance(membership_lock, bool):
            raise TypeError("Expected argument 'membership_lock' to be a bool")
        pulumi.set(__self__, "membership_lock", membership_lock)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if parent_id and not isinstance(parent_id, int):
            raise TypeError("Expected argument 'parent_id' to be a int")
        pulumi.set(__self__, "parent_id", parent_id)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)
        if prevent_forking_outside_group and not isinstance(prevent_forking_outside_group, bool):
            raise TypeError("Expected argument 'prevent_forking_outside_group' to be a bool")
        pulumi.set(__self__, "prevent_forking_outside_group", prevent_forking_outside_group)
        if request_access_enabled and not isinstance(request_access_enabled, bool):
            raise TypeError("Expected argument 'request_access_enabled' to be a bool")
        pulumi.set(__self__, "request_access_enabled", request_access_enabled)
        if runners_token and not isinstance(runners_token, str):
            raise TypeError("Expected argument 'runners_token' to be a str")
        pulumi.set(__self__, "runners_token", runners_token)
        if shared_runners_minutes_limit and not isinstance(shared_runners_minutes_limit, int):
            raise TypeError("Expected argument 'shared_runners_minutes_limit' to be a int")
        pulumi.set(__self__, "shared_runners_minutes_limit", shared_runners_minutes_limit)
        if shared_runners_setting and not isinstance(shared_runners_setting, str):
            raise TypeError("Expected argument 'shared_runners_setting' to be a str")
        pulumi.set(__self__, "shared_runners_setting", shared_runners_setting)
        if shared_with_groups and not isinstance(shared_with_groups, list):
            raise TypeError("Expected argument 'shared_with_groups' to be a list")
        pulumi.set(__self__, "shared_with_groups", shared_with_groups)
        if visibility_level and not isinstance(visibility_level, str):
            raise TypeError("Expected argument 'visibility_level' to be a str")
        pulumi.set(__self__, "visibility_level", visibility_level)
        if web_url and not isinstance(web_url, str):
            raise TypeError("Expected argument 'web_url' to be a str")
        pulumi.set(__self__, "web_url", web_url)
        if wiki_access_level and not isinstance(wiki_access_level, str):
            raise TypeError("Expected argument 'wiki_access_level' to be a str")
        pulumi.set(__self__, "wiki_access_level", wiki_access_level)

    @_builtins.property
    @pulumi.getter(name="defaultBranch")
    def default_branch(self) -> _builtins.str:
        """
        The default branch of the group.
        """
        return pulumi.get(self, "default_branch")

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtection")
    def default_branch_protection(self) -> _builtins.int:
        """
        Whether developers and maintainers can push to the applicable default branch.
        """
        return pulumi.get(self, "default_branch_protection")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the group.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="extraSharedRunnersMinutesLimit")
    def extra_shared_runners_minutes_limit(self) -> _builtins.int:
        """
        Can be set by administrators only. Additional CI/CD minutes for this group.
        """
        return pulumi.get(self, "extra_shared_runners_minutes_limit")

    @_builtins.property
    @pulumi.getter(name="fullName")
    def full_name(self) -> _builtins.str:
        """
        The full name of the group.
        """
        return pulumi.get(self, "full_name")

    @_builtins.property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> _builtins.str:
        """
        The full path of the group.
        """
        return pulumi.get(self, "full_path")

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> _builtins.int:
        """
        The ID of the group.
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this datasource. In the format `<group-id>`.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lfsEnabled")
    def lfs_enabled(self) -> _builtins.bool:
        """
        Boolean, is LFS enabled for projects in this group.
        """
        return pulumi.get(self, "lfs_enabled")

    @_builtins.property
    @pulumi.getter(name="membershipLock")
    def membership_lock(self) -> _builtins.bool:
        """
        Users cannot be added to projects in this group.
        """
        return pulumi.get(self, "membership_lock")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of this group.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> _builtins.int:
        """
        Integer, ID of the parent group.
        """
        return pulumi.get(self, "parent_id")

    @_builtins.property
    @pulumi.getter
    def path(self) -> _builtins.str:
        """
        The path of the group.
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="preventForkingOutsideGroup")
    def prevent_forking_outside_group(self) -> _builtins.bool:
        """
        When enabled, users can not fork projects from this group to external namespaces.
        """
        return pulumi.get(self, "prevent_forking_outside_group")

    @_builtins.property
    @pulumi.getter(name="requestAccessEnabled")
    def request_access_enabled(self) -> _builtins.bool:
        """
        Boolean, is request for access enabled to the group.
        """
        return pulumi.get(self, "request_access_enabled")

    @_builtins.property
    @pulumi.getter(name="runnersToken")
    def runners_token(self) -> _builtins.str:
        """
        The group level registration token to use during runner setup.
        """
        return pulumi.get(self, "runners_token")

    @_builtins.property
    @pulumi.getter(name="sharedRunnersMinutesLimit")
    def shared_runners_minutes_limit(self) -> _builtins.int:
        """
        Can be set by administrators only. Maximum number of monthly CI/CD minutes for this group. Can be nil (default; inherit system default), 0 (unlimited), or > 0.
        """
        return pulumi.get(self, "shared_runners_minutes_limit")

    @_builtins.property
    @pulumi.getter(name="sharedRunnersSetting")
    def shared_runners_setting(self) -> _builtins.str:
        """
        Enable or disable shared runners for a group's subgroups and projects. Valid values are: `enabled`, `disabled_and_overridable`, `disabled_and_unoverridable`, `disabled_with_override`.
        """
        return pulumi.get(self, "shared_runners_setting")

    @_builtins.property
    @pulumi.getter(name="sharedWithGroups")
    def shared_with_groups(self) -> Sequence['outputs.GetGroupSharedWithGroupResult']:
        """
        Describes groups which have access shared to this group.
        """
        return pulumi.get(self, "shared_with_groups")

    @_builtins.property
    @pulumi.getter(name="visibilityLevel")
    def visibility_level(self) -> _builtins.str:
        """
        Visibility level of the group. Possible values are `private`, `internal`, `public`.
        """
        return pulumi.get(self, "visibility_level")

    @_builtins.property
    @pulumi.getter(name="webUrl")
    def web_url(self) -> _builtins.str:
        """
        Web URL of the group.
        """
        return pulumi.get(self, "web_url")

    @_builtins.property
    @pulumi.getter(name="wikiAccessLevel")
    def wiki_access_level(self) -> _builtins.str:
        """
        The group's wiki access level. Only available on Premium and Ultimate plans. Valid values are `disabled`, `private`, `enabled`.
        """
        return pulumi.get(self, "wiki_access_level")


class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            default_branch=self.default_branch,
            default_branch_protection=self.default_branch_protection,
            description=self.description,
            extra_shared_runners_minutes_limit=self.extra_shared_runners_minutes_limit,
            full_name=self.full_name,
            full_path=self.full_path,
            group_id=self.group_id,
            id=self.id,
            lfs_enabled=self.lfs_enabled,
            membership_lock=self.membership_lock,
            name=self.name,
            parent_id=self.parent_id,
            path=self.path,
            prevent_forking_outside_group=self.prevent_forking_outside_group,
            request_access_enabled=self.request_access_enabled,
            runners_token=self.runners_token,
            shared_runners_minutes_limit=self.shared_runners_minutes_limit,
            shared_runners_setting=self.shared_runners_setting,
            shared_with_groups=self.shared_with_groups,
            visibility_level=self.visibility_level,
            web_url=self.web_url,
            wiki_access_level=self.wiki_access_level)


def get_group(full_path: Optional[_builtins.str] = None,
              group_id: Optional[_builtins.int] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupResult:
    """
    The `Group` data source allows details of a group to be retrieved by its id or full path.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#get-a-single-group)


    :param _builtins.str full_path: The full path of the group.
    :param _builtins.int group_id: The ID of the group.
    """
    __args__ = dict()
    __args__['fullPath'] = full_path
    __args__['groupId'] = group_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult).value

    return AwaitableGetGroupResult(
        default_branch=pulumi.get(__ret__, 'default_branch'),
        default_branch_protection=pulumi.get(__ret__, 'default_branch_protection'),
        description=pulumi.get(__ret__, 'description'),
        extra_shared_runners_minutes_limit=pulumi.get(__ret__, 'extra_shared_runners_minutes_limit'),
        full_name=pulumi.get(__ret__, 'full_name'),
        full_path=pulumi.get(__ret__, 'full_path'),
        group_id=pulumi.get(__ret__, 'group_id'),
        id=pulumi.get(__ret__, 'id'),
        lfs_enabled=pulumi.get(__ret__, 'lfs_enabled'),
        membership_lock=pulumi.get(__ret__, 'membership_lock'),
        name=pulumi.get(__ret__, 'name'),
        parent_id=pulumi.get(__ret__, 'parent_id'),
        path=pulumi.get(__ret__, 'path'),
        prevent_forking_outside_group=pulumi.get(__ret__, 'prevent_forking_outside_group'),
        request_access_enabled=pulumi.get(__ret__, 'request_access_enabled'),
        runners_token=pulumi.get(__ret__, 'runners_token'),
        shared_runners_minutes_limit=pulumi.get(__ret__, 'shared_runners_minutes_limit'),
        shared_runners_setting=pulumi.get(__ret__, 'shared_runners_setting'),
        shared_with_groups=pulumi.get(__ret__, 'shared_with_groups'),
        visibility_level=pulumi.get(__ret__, 'visibility_level'),
        web_url=pulumi.get(__ret__, 'web_url'),
        wiki_access_level=pulumi.get(__ret__, 'wiki_access_level'))
def get_group_output(full_path: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     group_id: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupResult]:
    """
    The `Group` data source allows details of a group to be retrieved by its id or full path.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#get-a-single-group)


    :param _builtins.str full_path: The full path of the group.
    :param _builtins.int group_id: The ID of the group.
    """
    __args__ = dict()
    __args__['fullPath'] = full_path
    __args__['groupId'] = group_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult)
    return __ret__.apply(lambda __response__: GetGroupResult(
        default_branch=pulumi.get(__response__, 'default_branch'),
        default_branch_protection=pulumi.get(__response__, 'default_branch_protection'),
        description=pulumi.get(__response__, 'description'),
        extra_shared_runners_minutes_limit=pulumi.get(__response__, 'extra_shared_runners_minutes_limit'),
        full_name=pulumi.get(__response__, 'full_name'),
        full_path=pulumi.get(__response__, 'full_path'),
        group_id=pulumi.get(__response__, 'group_id'),
        id=pulumi.get(__response__, 'id'),
        lfs_enabled=pulumi.get(__response__, 'lfs_enabled'),
        membership_lock=pulumi.get(__response__, 'membership_lock'),
        name=pulumi.get(__response__, 'name'),
        parent_id=pulumi.get(__response__, 'parent_id'),
        path=pulumi.get(__response__, 'path'),
        prevent_forking_outside_group=pulumi.get(__response__, 'prevent_forking_outside_group'),
        request_access_enabled=pulumi.get(__response__, 'request_access_enabled'),
        runners_token=pulumi.get(__response__, 'runners_token'),
        shared_runners_minutes_limit=pulumi.get(__response__, 'shared_runners_minutes_limit'),
        shared_runners_setting=pulumi.get(__response__, 'shared_runners_setting'),
        shared_with_groups=pulumi.get(__response__, 'shared_with_groups'),
        visibility_level=pulumi.get(__response__, 'visibility_level'),
        web_url=pulumi.get(__response__, 'web_url'),
        wiki_access_level=pulumi.get(__response__, 'wiki_access_level')))
